@@ -28,6 +28,7 @@
 #include <kitemviews/kitemrange.h>
 #include <kitemviews/kitemset.h>
 
+#include <QUrl>
 #include <QHash>
 #include <QObject>
 #include <QVariant>
@@ -182,6 +183,20 @@ public:
      */
     QString blacklistItemDropEventMimeType() const;
 
+    /**
+     * @return URL of the item at the specified index
+     */
+    virtual QUrl url(int index) const;
+
+    /**
+     * @return True, if item at specified index is a directory
+     */
+    virtual bool isDir(int index) const;
+
+    /**
+     * @return Parent directory of the items that are shown
+     */
+    virtual QUrl directory() const;
 signals:
     /**
      * Is emitted if one or more items have been inserted. Each item-range consists
