@@ -85,12 +85,20 @@ private slots:
 
 
 private:
+    /**
+     * Indicate if it is allowed to leave current location.
+     */
+    enum NavigationBehaviour {
+      StayWhereYouAre,  ///< Don't leave current location.
+      AllowJumpHome     ///< Go Home only when context menu option got checked.
+    };
     /**
      * Initializes the base URL of the tree and expands all
      * directories until \a url.
      * @param url  URL of the leaf directory that should get expanded.
+     * @param navigationBehaviour Navigation behaviour \see NavigationBehaviour
      */
-    void loadTree(const QUrl& url);
+    void loadTree(const QUrl& url, NavigationBehaviour navigationBehaviour = StayWhereYouAre);
 
     void reloadTree();
 
