@@ -27,7 +27,7 @@
 #include <KLocalizedString>
 #include <KNS3/KMoreToolsMenuFactory>
 #include <KIO/Job>
-
+#include <knewstuff_version.h>
 
 StatusBarSpaceInfo::StatusBarSpaceInfo(QWidget* parent) :
     KCapacityBar(KCapacityBar::DrawTextInline, parent),
@@ -78,6 +78,9 @@ void StatusBarSpaceInfo::mousePressEvent(QMouseEvent* event)
         // Note that this object must live long enough in case the user opens
         // the "Configure..." dialog
         KMoreToolsMenuFactory menuFactory(QStringLiteral("dolphin/statusbar-diskspace-menu"));
+#if KNEWSTUFF_VERSION >= QT_VERSION_CHECK(5, 37, 0)
+        menuFactory.setParentWidget(this);
+#endif
         auto menu = menuFactory.createMenuFromGroupingNames(
             { "disk-usage", "more:", "disk-partitions" }, m_url);
 
