@@ -22,9 +22,10 @@
 #define DRAGANDDROPHELPER_H
 
 #include "dolphin_export.h"
+#include <QList>
+#include <QUrl>
 
 
-class QUrl;
 class QDropEvent;
 class QWidget;
 namespace KIO { class DropJob; }
@@ -42,11 +43,17 @@ public:
      *                  is true.
      * @param event     Drop event.
      * @param window    Widget where the drop happened, will be used as parent of the drop menu.
-     * @return          KIO::DropJob pointer
+     * @return          KIO::DropJob pointer or null in case the destUrl is contained
+     *                  in the mimeData url list.
      */
     static KIO::DropJob* dropUrls(const QUrl& destUrl,
                                   QDropEvent* event,
                                   QWidget *window);
+
+    /**
+     * @return True if destUrl is contained in the urls parameter.
+     */
+    static bool urlListMatchesUrl(const QList<QUrl>& urls, const QUrl& destUrl);
 };
 
 #endif
